..
    SPDX-License-Identifier: AGPL-3.0-or-later
    Copyright (C) 2025  Dionisis Toulatos

Quickstart
##########

After :doc:`installation <install>`, the library can be used in any Python project.
For more examples see :doc:`dev/examples`.

.. seealso::

    If you don't have an MQTT broker installed on Home Assistant,
    like `Mosquitto <https://mosquitto.org/>`_, have a look at the
    `documentation <https://www.home-assistant.io/integrations/mqtt#broker-configuration>`_.

.. tip::

    For documentation of each MQTT component refer to the Home Assistant
    `MQTT documentation <https://www.home-assistant.io/integrations/mqtt#configuration>`_.
